#[non_exhaustive]pub enum LayerRole {
Weight,
Property,
}Expand description
Declared role of a property layer.
Performance
Copying, comparing, ordering, hashing, and debug-formatting are O(1).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Weight
Layer is intended to be selected as a topology weight capability.
Property
Layer is a named property with no required weight interpretation.