#[non_exhaustive]pub enum StorageMode {
Dense,
Sparse {
missing: MissingPolicy,
},
}Expand description
Physical storage mode for a property layer.
Performance
Copying, comparing, and debug-formatting are O(1).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Dense
Dense array with one slot per ID index.
Sparse
Sparse array keyed by explicit indexes plus a missing-value policy.
Fields

missing: MissingPolicyPolicy used for indexes not present in the sparse index array.