PropertySnapshotMetaWord

Trait PropertySnapshotMetaWord 

pub trait PropertySnapshotMetaWord: PropertySnapshotMetaWord + PropertyIndex {
    const PROPERTY_DESCRIPTORS_KIND: u32;
    const PROPERTY_DATA_KIND: u32;
    const IDENTITY_MODES_KIND: u32;
    const ELEMENT_IDENTITY_MAP_KIND: u32;
    const RELATION_IDENTITY_MAP_KIND: u32;
    const INCIDENCE_IDENTITY_MAP_KIND: u32;
}
Metadata/canonical-ID word width for property and identity snapshot sections.

Performance

Implementations perform checked conversions in O(1).

Required Associated Constants

const PROPERTY_DESCRIPTORS_KIND: u32

Property descriptor section kind for this metadata width.

const PROPERTY_DATA_KIND: u32

Property data section kind for this metadata width.

const IDENTITY_MODES_KIND: u32

Identity mode section kind for this metadata width.

const ELEMENT_IDENTITY_MAP_KIND: u32

Element identity map section kind for this metadata width.

const RELATION_IDENTITY_MAP_KIND: u32

Relation identity map section kind for this metadata width.

const INCIDENCE_IDENTITY_MAP_KIND: u32

Incidence identity map section kind for this metadata width.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl PropertySnapshotMetaWord for u16

Source

const PROPERTY_DESCRIPTORS_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DESCRIPTORS_U16

Source

const PROPERTY_DATA_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DATA_U16

Source

const IDENTITY_MODES_KIND: u32 = SNAPSHOT_KIND_IDENTITY_MODES_U16

Source

const ELEMENT_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_ELEMENT_IDENTITY_MAP_U16

Source

const RELATION_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_RELATION_IDENTITY_MAP_U16

Source

const INCIDENCE_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_INCIDENCE_IDENTITY_MAP_U16

Source

impl PropertySnapshotMetaWord for u32

Source

const PROPERTY_DESCRIPTORS_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DESCRIPTORS_U32

Source

const PROPERTY_DATA_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DATA_U32

Source

const IDENTITY_MODES_KIND: u32 = SNAPSHOT_KIND_IDENTITY_MODES_U32

Source

const ELEMENT_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_ELEMENT_IDENTITY_MAP_U32

Source

const RELATION_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_RELATION_IDENTITY_MAP_U32

Source

const INCIDENCE_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_INCIDENCE_IDENTITY_MAP_U32

Source

impl PropertySnapshotMetaWord for u64

Source

const PROPERTY_DESCRIPTORS_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DESCRIPTORS_U64

Source

const PROPERTY_DATA_KIND: u32 = SNAPSHOT_KIND_PROPERTY_DATA_U64

Source

const IDENTITY_MODES_KIND: u32 = SNAPSHOT_KIND_IDENTITY_MODES_U64

Source

const ELEMENT_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_ELEMENT_IDENTITY_MAP_U64

Source

const RELATION_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_RELATION_IDENTITY_MAP_U64

Source

const INCIDENCE_IDENTITY_MAP_KIND: u32 = SNAPSHOT_KIND_INCIDENCE_IDENTITY_MAP_U64

Implementors