#[non_exhaustive]pub enum PropertyError {
Show 31 variants
EmptyLayerName,
ExpectedDenseStorage {
name: LayerName,
},
ExpectedSparseStorage {
name: LayerName,
},
DefaultPolicyMismatch {
name: LayerName,
},
ArrowTypeMismatch {
name: LayerName,
},
IdFamilyMismatch {
expected: IdFamily,
actual: IdFamily,
},
LayerTooShort {
required: usize,
actual: usize,
},
UnexpectedNull {
index: usize,
},
SparseLengthMismatch {
indices: usize,
values: usize,
},
SparseIndexOrder {
position: usize,
},
SparseIndexOutOfBounds {
index: u64,
len: usize,
},
DuplicateName {
id_family: IdFamily,
name: LayerName,
},
SparseNullMissingNotTotal {
name: LayerName,
},
DuplicateLayerId {
layer_id: u64,
},
MissingSnapshotSection {
kind: u32,
},
SnapshotSectionVersion {
kind: u32,
version: u32,
},
SnapshotSectionView {
kind: u32,
error: SectionViewError,
},
SnapshotRangeOutOfBounds {
offset: usize,
len: usize,
available: usize,
},
SnapshotInvalidUtf8 {
offset: usize,
},
UnknownIdFamilyTag {
tag: u32,
},
UnknownLayerRoleTag {
tag: u32,
},
UnknownStorageTag {
tag: u32,
},
UnknownMissingPolicyTag {
tag: u32,
},
UnknownArrowFamilyTag {
tag: u32,
},
UnknownIdentityModeTag {
tag: u32,
},
SnapshotDescriptorMismatch {
reason: &'static str,
},
SnapshotDataLength {
reason: &'static str,
},
Arrow {
message: String,
},
MissingIdentityMap {
id_family: IdFamily,
},
IdentityMapLength {
id_family: IdFamily,
required: usize,
actual: usize,
},
LengthDoesNotFitU64 {
value: usize,
},
}Expand description
Errors raised while validating property descriptors, layers, or snapshots.
Performance
Formatting is O(message length).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EmptyLayerName
Layer names must not be empty.
ExpectedDenseStorage
Dense layers must use dense descriptors.
ExpectedSparseStorage
Sparse layers must use sparse descriptors.
DefaultPolicyMismatch
A sparse descriptor and default value disagreed.
ArrowTypeMismatch
A layer’s Arrow data type did not match the descriptor field type.
IdFamilyMismatch
A layer’s ID family did not match the requested adapter family.
LayerTooShort
A layer had too few values for the topology index bound.
UnexpectedNull
A non-nullable selected layer contained a null slot.
SparseLengthMismatch
Sparse index and value arrays differed in length.
SparseIndexOrder
Sparse indexes must be strictly increasing.
SparseIndexOutOfBounds
Sparse index was outside the declared logical length.
DuplicateName
A name was reused within an ID-family namespace.
SparseNullMissingNotTotal
Sparse null-missing policy cannot be selected as a total weight view.
DuplicateLayerId
A layer ID was reused within one descriptor set.
MissingSnapshotSection
A snapshot section was missing.
SnapshotSectionVersion
A snapshot section had an unsupported version.
SnapshotSectionView
A snapshot section could not be borrowed as the expected record type.
SnapshotRangeOutOfBounds
Snapshot bytes ended before a declared range.
Fields
SnapshotInvalidUtf8
Snapshot string table bytes were not valid UTF-8.
UnknownIdFamilyTag
Snapshot metadata used an unknown ID family tag.
UnknownLayerRoleTag
Snapshot metadata used an unknown layer role tag.
UnknownStorageTag
Snapshot metadata used an unknown storage tag.
UnknownMissingPolicyTag
Snapshot metadata used an unknown missing-policy tag.
UnknownArrowFamilyTag
Snapshot metadata used an unknown Arrow value-family tag.
UnknownIdentityModeTag
Snapshot metadata used an unknown identity-map mode tag.
SnapshotDescriptorMismatch
A property snapshot descriptor was structurally inconsistent.
SnapshotDataLength
A property data payload had an invalid byte length.
Arrow
Arrow IPC/schema validation failed.
MissingIdentityMap
An explicit identity map was required but missing.
IdentityMapLength
An identity map length did not match its mode metadata.
Fields
LengthDoesNotFitU64
A usize value could not be represented as u64.