pub trait PropertySnapshotMetaWord: PropertySnapshotMetaWord + PropertyIndex {
const PROPERTY_DESCRIPTORS_KIND: u32;
const PROPERTY_DATA_KIND: u32;
const IDENTITY_MODES_KIND: u32;
const ELEMENT_IDENTITY_MAP_KIND: u32;
const RELATION_IDENTITY_MAP_KIND: u32;
const INCIDENCE_IDENTITY_MAP_KIND: u32;
}Expand description
Metadata/canonical-ID word width for property and identity snapshot sections.
Performance
Implementations perform checked conversions in O(1).
Required Associated Constants
Sourceconst PROPERTY_DESCRIPTORS_KIND: u32
const PROPERTY_DESCRIPTORS_KIND: u32
Property descriptor section kind for this metadata width.
Sourceconst PROPERTY_DATA_KIND: u32
const PROPERTY_DATA_KIND: u32
Property data section kind for this metadata width.
Sourceconst IDENTITY_MODES_KIND: u32
const IDENTITY_MODES_KIND: u32
Identity mode section kind for this metadata width.
Sourceconst ELEMENT_IDENTITY_MAP_KIND: u32
const ELEMENT_IDENTITY_MAP_KIND: u32
Element identity map section kind for this metadata width.
Sourceconst RELATION_IDENTITY_MAP_KIND: u32
const RELATION_IDENTITY_MAP_KIND: u32
Relation identity map section kind for this metadata width.
Sourceconst INCIDENCE_IDENTITY_MAP_KIND: u32
const INCIDENCE_IDENTITY_MAP_KIND: u32
Incidence identity map section kind for this metadata width.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".